==> aliyun-python-sdk-imm-1.3.2.tar.gz: aliyun-python-sdk-imm-1.3.2/aliyunsdkimm/request/v20170906/ListTagJobsRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
class ListTagJobsRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'imm', '2017-09-06', 'ListTagJobs','imm')

	def get_Condition(self):
		return self.get_query_params().get('Condition')

	def set_Condition(self,Condition):
		self.add_query_param('Condition',Condition)

	def get_MaxKeys(self):
		return self.get_query_params().get('MaxKeys')

	def set_MaxKeys(self,MaxKeys):
		self.add_query_param('MaxKeys',MaxKeys)

	def get_Marker(self):
		return self.get_query_params().get('Marker')

	def set_Marker(self,Marker):
		self.add_query_param('Marker',Marker)

	def get_Project(self):
		return self.get_query_params().get('Project')

	def set_Project(self,Project):
		self.add_query_param('Project',Project)

==> aliyun-python-sdk-imm-1.6.2.tar.gz: aliyun-python-sdk-imm-1.6.2/aliyunsdkimm/request/v20170906/ListTagJobsRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
class ListTagJobsRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'imm', '2017-09-06', 'ListTagJobs','2017-09-06')

	def get_Condition(self):
		return self.get_query_params().get('Condition')

	def set_Condition(self,Condition):
		self.add_query_param('Condition',Condition)

	def get_MaxKeys(self):
		return self.get_query_params().get('MaxKeys')

	def set_MaxKeys(self,MaxKeys):
		self.add_query_param('MaxKeys',MaxKeys)

	def get_Marker(self):
		return self.get_query_params().get('Marker')

	def set_Marker(self,Marker):
		self.add_query_param('Marker',Marker)

	def get_Project(self):
		return self.get_query_params().get('Project')

	def set_Project(self,Project):
		self.add_query_param('Project',Project)
